# Reference Catalog: Provider Tiers, Response Times, and FAQs
### On this page
  * [Provider Tiers and Response Times](https://help.sap.com/docs/leanix/ea/reference-catalog-provider-tiers-response-times-and-faqs#provider-tiers-and-response-times)
  * [Tiers for Applications in the Catalog](https://help.sap.com/docs/leanix/ea/reference-catalog-provider-tiers-response-times-and-faqs#tiers-for-applications-in-the-catalog)
  * [Tiers for IT Components in the Catalog](https://help.sap.com/docs/leanix/ea/reference-catalog-provider-tiers-response-times-and-faqs#tiers-for-it-components-in-the-catalog)
  * [Frequently Asked Questions](https://help.sap.com/docs/leanix/ea/reference-catalog-provider-tiers-response-times-and-faqs#frequently-asked-questions)


Learn more about provider tiers and response time for additional or missing data and find answers to frequently asked questions.
In this document, you can find additional information about the reference catalog. To learn about the reference catalog, its benefits, and the data available in it, see [Reference Catalog](https://help.sap.com/docs/leanix/ea/reference-catalog?locale=en-US&state=PRODUCTION&version=CLOUD "The reference catalog provides reference data for business capabilities, applications, IT components, and tech categories, which enables you to set up and maintain your inventory more efficiently.").
